@@ -20,13 +20,12 @@
  */
 
 #include "Internal.h"
+#include <errno.h>
 
 #ifdef DMALLOC
 #include "dmalloc.h"
 #endif
 
-extern int errno;
-
 #ifndef LIBJUAFS
 // user class and fields //
 jclass userCls = 0;
