@@ -875,9 +875,15 @@ struct cm_initparams {
 #define	IFAnyPages	32
 #define	IFDiscarded	64	/* index entry in discardDCList */
 
+#ifdef AFS_DARWIN100_ENV
+typedef user_addr_t iparmtype; /* 64 bit */
+#else
+typedef char * iparmtype;
+#endif
+
 struct afs_ioctl {
-    char *in;			/* input buffer */
-    char *out;			/* output buffer */
+    iparmtype in;		/* input buffer */
+    iparmtype out;		/* output buffer */
     short in_size;		/* Size of input buffer <= 2K */
     short out_size;		/* Maximum size of output buffer, <= 2K */
 };
