@@ -1,5 +1,5 @@
 /* 
- * $Id: aklog_main.c,v 1.1.2.31 2009/03/15 18:02:52 shadow Exp $
+ * $Id$
  *
  * Copyright 1990,1991 by the Massachusetts Institute of Technology
  * For distribution and copying rights, see the file "mit-copyright.h"
@@ -35,8 +35,7 @@
  */
 
 #include <afsconfig.h>
-RCSID
-     ("$Header: /cvs/openafs/src/aklog/aklog_main.c,v 1.1.2.31 2009/03/15 18:02:52 shadow Exp $");
+
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
@@ -1259,6 +1258,19 @@ void aklog(int argc, char *argv[])
     krb5_init_context(&context);
     initialize_ktc_error_table ();
 
+    /*
+     * Enable DES enctypes, which are currently still required for AFS.
+     * krb5_allow_weak_crypto is MIT Kerberos 1.8.  krb5_enctype_enable is
+     * Heimdal.
+     */
+#if defined(HAVE_KRB5_ALLOW_WEAK_CRYPTO)
+    krb5_allow_weak_crypto(context, 1);
+#elif defined(HAVE_KRB5_ENCTYPE_ENABLE)
+    i = krb5_enctype_valid(context, ETYPE_DES_CBC_CRC);
+    if (i)
+        krb5_enctype_enable(context, ETYPE_DES_CBC_CRC);
+#endif
+
     /* Initialize list of cells to which we have authenticated */
     (void)ll_init(&authedcells);
 
