@@ -62,6 +62,10 @@
 #define SYS_NAME_ID_x86_darwin_80        509
 #define SYS_NAME_ID_ppc_darwin_90        510
 #define SYS_NAME_ID_x86_darwin_90        511
+#define SYS_NAME_ID_ppc_darwin_100       512
+#define SYS_NAME_ID_ppc64_darwin_100     513
+#define SYS_NAME_ID_x86_darwin_100       514
+#define SYS_NAME_ID_amd64_darwin_100     515
 
 #define SYS_NAME_ID_next_mach20		 601
 #define SYS_NAME_ID_next_mach30		 602
@@ -250,6 +254,8 @@
 #define SYS_NAME_ID_i386_obsd43         2612
 #define SYS_NAME_ID_i386_obsd44         2613
 #define SYS_NAME_ID_i386_obsd45         2614
+#define SYS_NAME_ID_i386_obsd46         2615
+#define SYS_NAME_ID_i386_obsd47         2616
 
 #define SYS_NAME_ID_amd64_linux2        2700
 #define SYS_NAME_ID_amd64_linux22       2701
