@@ -31,9 +31,9 @@
 #define AFS_SYSCALL 137
 #define AFS_64BIT_IOPS_ENV  1
 #define AFS_NAMEI_ENV     1	/* User space interface to file system */
+#define AFS_MAXVCOUNT_ENV       1
 
 #if defined(__KERNEL__) && !defined(KDUMP_KERNEL)
-#include <linux/config.h>
 #ifdef CONFIG_SMP
 #undef CONFIG_SMP
 #endif
@@ -48,8 +48,8 @@
 #ifndef __SMP__
 #define __SMP__
 #endif
-#define AFS_GLOBAL_SUNLOCK
 #endif
+#define AFS_GLOBAL_SUNLOCK
 
 #if defined(MODULE) && defined(CONFIG_MODVERSIONS)
 #define MODVERSIONS
@@ -71,6 +71,7 @@
 #define AFS_HAVE_FFS        1	/* Use system's ffs. */
 #define AFS_HAVE_STATVFS    0	/* System doesn't support statvfs */
 #define AFS_VM_RDWR_ENV	    1	/* read/write implemented via VM */
+#define AFS_USE_GETTIMEOFDAY       1	/* use gettimeofday to implement rx clock */
 
 #ifdef KERNEL
 #ifndef MIN
