@@ -16,20 +16,11 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/gtx/textcb.c,v 1.7 2003/07/15 23:15:13 shadow Exp $");
 
 #include "gtxtextcb.h"		/*Module interface */
 #include <stdio.h>		/*Standard I/O stuff */
 #include <errno.h>
-
-#ifdef HAVE_STRING_H
 #include <string.h>
-#else
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-#endif
 #include <stdlib.h>
 
 static int gator_textcb_debug;	/*Is debugging output turned on? */
